@@ -1,7 +1,7 @@
 /* vim: set noet ts=4:
  *
  * Copyright (c) 1999 Michael G. Henderson <mghenderson@lanl.gov>.
- * Copyright (c) 2002-2016 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2019 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -61,7 +61,7 @@ CURL
 static struct memory
 	header = {NULL, 0};
 char
-	url[]       = "http://tgftp.nws.noaa.gov/data/observations/metar/decoded/\0\0\0\0.TXT",
+	url[]       = "https://tgftp.nws.noaa.gov/data/observations/metar/decoded/\0\0\0\0.TXT",
 	xtitle[]    = "weather report for \0\0\0\0\0",
 	*station    = NULL,
 	*report     = NULL,
@@ -519,12 +519,12 @@ static void do_opts(int argc, char *argv[])
 			printf("  --wgc=<color>         gusty-wind (variable direction) color,\n");
 			printf("  --tc=<color>          station ID and time color.\n");
 			printf("System-wide configuration file is %s.\n", SYSCONFPATH);
-			printf("For ICAO location indicators visit http://www.nws.noaa.gov/tg/siteloc.php.\n");
+			printf("For ICAO location indicators visit https://en.wikipedia.org/wiki/ICAO_airport_code.\n");
 			exit(0);
 		case 'v':
 			printf("%s\n", PACKAGE_STRING);
 			printf("copyright (c) 1999 Michael G. Henderson <mghenderson@lanl.gov>\n");
-			printf("copyright (c) 2002-2016 Martin A. Godisch <martin@godisch.de>\n");
+			printf("copyright (c) 2002-2019 Martin A. Godisch <martin@godisch.de>\n");
 			exit(0);
 		case 0:
 		case 1:
